@@ -10,7 +10,7 @@ struct MD5Context {
 void MD5Init(struct MD5Context *context);
 void MD5Update(struct MD5Context *context, unsigned char const *buf,
 	       unsigned len);
-void MD5Final(unsigned char digest[16], struct MD5Context *context);
+void MD5Final(struct MD5Context *context, unsigned char *digest);
 void MD5Transform(word32 buf[4], word32 const in[16]);
 
 /*
